/*
  Библиотека LiquidCrystal - последовательный ввод

  Демонстрирует использование ЖК-дисплея 16x2. Библиотека LiquidCrystal 
  работает со всеми ЖК-дисплеями, совместимыми с драйвером Hitachi HD44780. 
  Их много, и обычно вы можете определить их по 16-контактному интерфейсу.

  Этот эскиз отображает текст, отправленный через последовательный порт 
  (например, с последовательного монитора) на подключенном ЖК-дисплее.

  Схема:
  * Вывод ЖК-дисплея RS на цифровой вывод 12
  * ЖК-дисплей Enable вывод на цифровой вывод 11
  * Вывод ЖК-дисплея D4 на цифровой вывод 5
  * Вывод ЖК-дисплея D5 на цифровой вывод 4
  * Вывод ЖК-дисплея D6 на цифровой вывод 3
  * Вывод ЖК-дисплея D7 на цифровой вывод 2
  * Вывод ЖК-дисплея R/W контакт к земле
  * Резистор 10 кОм:
  * подключается к + 5В и на землю
  * средний контакт к выводу ЖК-дисплея VO (вывод 3)

  Библиотека изначально добавлена 18 апреля 2008 г.
  Дэвид А. Меллис
  библиотека изменена 5 июля 2009 г.
  Лимор Фрид (http://www.ladyada.net)
  пример добавлен 9 июля 2009 г.
  Том Igoe
  изменен 22 ноября 2010 г.
  Том Igoe
  изменен 7 нояб.2016 г.
  Артуро Гуадалупи

  Этот пример кода находится в общественном достоянии.

 http://www.arduino.cc/en/Tutorial/LiquidCrystalSerialDisplay

*/

// Подключаем библиотеку:
#include <LiquidCrystal.h>

// инициализировать библиотеку, связав любой необходимый вывод 
// интерфейса ЖК-дисплея с номером вывода Arduino, к которому он подключен
const int rs = 12, en = 11, d4 = 5, d5 = 4, d6 = 3, d7 = 2;
LiquidCrystal lcd(rs, en, d4, d5, d6, d7);

void setup() {
  // настроить количество столбцов и строк на ЖК-дисплее:
  lcd.begin(16, 2);
  // инициализировать последовательную связь:
  Serial.begin(9600);
}

void loop() {
  // когда символы прибывают через последовательный порт ...
  if (Serial.available()) {
    // подождать немного, чтобы пришло все сообщение
    delay(100);
    // очистить экран
    lcd.clear();
    // прочитать все доступные символы
    while (Serial.available() > 0) {
      // отображать каждый символ на ЖК-дисплее
      lcd.write(Serial.read());
    }
  }
}
